@@ -1,3 +1,5 @@
+from typing import List
+
 import requests
 import io
 import pyarrow as pa
@@ -5,6 +7,18 @@ import pyarrow.parquet as pq
 import json
 import pandas as pd
 
+
+class StorageEntry:
+    key: str
+    value: str
+    datetime: str
+    tags: [str]
+
+class FilterEntry:
+    key: str
+    tags: [str]
+
+
 class ChipmunkDb():
     def __init__(self, host, port=8091, autoConnect=True):
         self.host = host
@@ -50,7 +64,7 @@ class ChipmunkDb():
     def save_document(self, directory, document, data, type="single"):
         res = requests.post(url=self.getHostAndPort()+"/directory/"+directory+"/"+document, data=json.dumps({"data": data, "type": type}))
         retdata = res.json()
-        if "error" in data:
+        if "error" in retdata:
             return None
         return retdata["data"]
 
@@ -106,7 +120,32 @@ class ChipmunkDb():
 
         return df
 
+    def storages(self):
+        res = requests.get(url=self.getHostAndPort()+"/storages")
+        return res.json()["storages"]
 
+    def drop_storage(self, storage):
+        res = requests.delete(url=self.getHostAndPort()+"/storage/"+storage)
+        return res.json()["success"]
+
+    def get_storage(self, storage):
+        res = requests.get(url=self.getHostAndPort()+"/storage/"+storage)
+        return res.json()["data"]
+
+    def filter_storage(self, storage, filters: List[FilterEntry]):
+        res = requests.post(url=self.getHostAndPort()+"/storage/"+storage+"/filter", data=json.dumps(filters))
+        if res.status_code != 200:
+            raise(res.json()["message"])
+        return res.json()["data"]
+
+
+    def save_keys_to_storage(self, storage, keys: List[StorageEntry]):
+        res = requests.post(url=self.getHostAndPort()+"/storage/"+storage, data=json.dumps(keys))
+        return res.json()["count"]
+
+    def get_key_for_storage(self, storage, key):
+        res = requests.get(url=self.getHostAndPort()+"/storage/"+storage+"/"+key)
+        return res.json()["data"]
 
 def main():
-    print("Running")
\ No newline at end of file
+    pass
\ No newline at end of file
